@@ -5,7 +5,7 @@ Usage:
 
 Options:
   template   path to the jinja2 template
-  namespace  AWS namespace. Currently supports: elb, ec2, rds
+  namespace  AWS namespace. Currently supports: elasticache, elb, ec2, rds
   region     AWS region [default: us-east-1]
   options    key value combinations, they can be tags or any other property
 
@@ -36,9 +36,12 @@ import boto
 import boto.ec2
 import boto.ec2.elb
 import boto.rds
+import boto.elasticache
 import jinja2
 
 
+__version__ = '0.5.0'
+
 # DEFAULT_NAMESPACE = 'ec2'  # TODO
 DEFAULT_REGION = 'us-east-1'
 
@@ -125,14 +128,30 @@ def list_rds(region, filter_by_kwargs):
     return lookup(instances, filter_by=filter_by_kwargs)
 
 
+def list_elasticache(region, filter_by_kwargs):
+    """List all ElastiCache Clusters."""
+    clusters = []
+    conn = boto.elasticache.connect_to_region(region)
+    req = conn.describe_cache_clusters()
+    data = req["DescribeCacheClustersResponse"]["DescribeCacheClustersResult"]["CacheClusters"]
+    for cluster in data:
+        CacheClusterId = cluster["CacheClusterId"]
+        clusters.append(CacheClusterId)
+    return clusters
+
+
 list_resources = {
     'ec2': list_ec2,
     'elb': list_elb,
     'rds': list_rds,
+    'elasticache': list_elasticache,
 }
 
 
 def main():
+    if '--version' in sys.argv:
+        print(__version__)
+        sys.exit()
     if len(sys.argv) < 3:
         print(__doc__)
         sys.exit()
@@ -153,7 +172,7 @@ def main():
         resources = list_resources[namespace](region, filters)
     except KeyError:
         print('ERROR: AWS namespace "{}" not supported or does not exist'
-            .format(namespace))
+              .format(namespace))
         sys.exit(1)
 
     print(template.render({
